==> download.php?dl=KompexSQLiteWrapperDoxygen_1.9.11.tar.gz: KompexSQLiteWrapperDoxygen_1.9.11/search/all_73.js <==
var searchData=
[
  ['savedatabasefrommemorytofile',['SaveDatabaseFromMemoryToFile',['../class_kompex_1_1_s_q_lite_database.html#a3812e7e890ccee4489a7ec12d8b08f3c',1,'Kompex::SQLiteDatabase::SaveDatabaseFromMemoryToFile(const std::string &amp;filename=&quot;&quot;)'],['../class_kompex_1_1_s_q_lite_database.html#a79c8ef4fa3cb182e4f8fb7c103f160c8',1,'Kompex::SQLiteDatabase::SaveDatabaseFromMemoryToFile(const wchar_t *filename)']]],
  ['securetransaction',['SecureTransaction',['../class_kompex_1_1_s_q_lite_statement.html#a98943e3ce6e26a01b9c58bf01050bd33',1,'Kompex::SQLiteStatement::SecureTransaction(const char *sql)'],['../class_kompex_1_1_s_q_lite_statement.html#af5e97de1dd47d4d84ee02879927a5f0d',1,'Kompex::SQLiteStatement::SecureTransaction(const std::string sql)'],['../class_kompex_1_1_s_q_lite_statement.html#a64aa6c6c48b65fdec05163723b213e15',1,'Kompex::SQLiteStatement::SecureTransaction(const wchar_t *sql)']]],
  ['setsoftheaplimit',['SetSoftHeapLimit',['../class_kompex_1_1_s_q_lite_database.html#ac1a2d8526e91070eaa329abeaa926584',1,'Kompex::SQLiteDatabase']]],
  ['show',['Show',['../class_kompex_1_1_s_q_lite_exception.html#adf5425fa24f82d3fed40ae7374348a62',1,'Kompex::SQLiteException']]],
  ['sql',['Sql',['../class_kompex_1_1_s_q_lite_statement.html#a92e61596d95ea0e10c6cfe854d4dd97c',1,'Kompex::SQLiteStatement::Sql(const std::string &amp;sql)'],['../class_kompex_1_1_s_q_lite_statement.html#afcf5e04dadfe3dfd4f30bd96157de6b6',1,'Kompex::SQLiteStatement::Sql(const char *sql)'],['../class_kompex_1_1_s_q_lite_statement.html#a14933c42155e21268f6e1b3e62a77bde',1,'Kompex::SQLiteStatement::Sql(const std::wstring &amp;sql)'],['../class_kompex_1_1_s_q_lite_statement.html#a86e38aec89f694482c028c9bbfc04052',1,'Kompex::SQLiteStatement::Sql(const wchar_t *sql)']]],
  ['sqlaggregatefuncresult',['SqlAggregateFuncResult',['../class_kompex_1_1_s_q_lite_statement.html#aa2c1ad017ba60efee37b98819f1e8ca8',1,'Kompex::SQLiteStatement::SqlAggregateFuncResult(const std::string &amp;countSql)'],['../class_kompex_1_1_s_q_lite_statement.html#a8488d05fc3c0d36deb1fde0d27a90339',1,'Kompex::SQLiteStatement::SqlAggregateFuncResult(wchar_t *countSql)'],['../class_kompex_1_1_s_q_lite_statement.html#aa8f3bd27d91d1bd42c666c00812870a6',1,'Kompex::SQLiteStatement::SqlAggregateFuncResult(const char *countSql)']]],
  ['sqliteblob',['SQLiteBlob',['../class_kompex_1_1_s_q_lite_blob.html',1,'Kompex']]],
  ['sqliteblob',['SQLiteBlob',['../class_kompex_1_1_s_q_lite_blob.html#a5dbd102cbd365507e9ad2f5e399e11de',1,'Kompex::SQLiteBlob::SQLiteBlob()'],['../class_kompex_1_1_s_q_lite_blob.html#a6f9401272a8bb90bb18eb7b35ea5b6d5',1,'Kompex::SQLiteBlob::SQLiteBlob(SQLiteDatabase *db, std::string symbolicDatabaseName, std::string tableName, std::string columnName, int64 rowId, BLOB_ACCESS_MODE accessMode=BLOB_READWRITE)']]],
  ['sqlitedatabase',['SQLiteDatabase',['../class_kompex_1_1_s_q_lite_database.html',1,'Kompex']]],
  ['sqlitedatabase',['SQLiteDatabase',['../class_kompex_1_1_s_q_lite_database.html#afb155f1329a190446144a1a30c9bae0f',1,'Kompex::SQLiteDatabase::SQLiteDatabase()'],['../class_kompex_1_1_s_q_lite_database.html#aa6a11b3db582b88901e08f44dd616906',1,'Kompex::SQLiteDatabase::SQLiteDatabase(const char *filename, int flags, const char *zVfs)'],['../class_kompex_1_1_s_q_lite_database.html#a3f3d2d17f265e16ad37c8d6c78140fee',1,'Kompex::SQLiteDatabase::SQLiteDatabase(const std::string &amp;filename, int flags, const char *zVfs)'],['../class_kompex_1_1_s_q_lite_database.html#a850b764cee6e62d6fafe486d7b8ef9da',1,'Kompex::SQLiteDatabase::SQLiteDatabase(const wchar_t *filename)']]],
  ['sqliteexception',['SQLiteException',['../class_kompex_1_1_s_q_lite_exception.html#a9b0c51d2919a6e6e2691f4d8a47d8717',1,'Kompex::SQLiteException::SQLiteException(const std::string &amp;filename, unsigned int line, std::string errDescription=&quot;&quot;)'],['../class_kompex_1_1_s_q_lite_exception.html#afae7153b3361354427c22958119586f1',1,'Kompex::SQLiteException::SQLiteException(const std::string &amp;filename, unsigned int line, const char *errDescription=&quot;&quot;)']]],
  ['sqliteexception',['SQLiteException',['../class_kompex_1_1_s_q_lite_exception.html',1,'Kompex']]],
  ['sqlitestatement',['SQLiteStatement',['../class_kompex_1_1_s_q_lite_statement.html',1,'Kompex']]],
  ['sqlitestatement',['SQLiteStatement',['../class_kompex_1_1_s_q_lite_statement.html#a99ef96c28884e3e0e60455589dda363a',1,'Kompex::SQLiteStatement']]],
  ['sqlresultblob',['SqlResultBlob',['../class_kompex_1_1_s_q_lite_statement.html#ace1f5cc6c309ac0af4110281a893b0be',1,'Kompex::SQLiteStatement']]],
  ['sqlresultcstring',['SqlResultCString',['../class_kompex_1_1_s_q_lite_statement.html#a7cd9332b0bdc9f357afd8fbf76f53a36',1,'Kompex::SQLiteStatement']]],
  ['sqlresultstring16',['SqlResultString16',['../class_kompex_1_1_s_q_lite_statement.html#abe7a8e3eefd854d8766dee84235d7177',1,'Kompex::SQLiteStatement']]],
  ['sqlstatement',['SqlStatement',['../class_kompex_1_1_s_q_lite_statement.html#aa489e189a08bef44ed00640a5ad27b01',1,'Kompex::SQLiteStatement::SqlStatement(const std::string &amp;sqlStatement)'],['../class_kompex_1_1_s_q_lite_statement.html#aa946886e893ac5f8e36452183ab4fa10',1,'Kompex::SQLiteStatement::SqlStatement(const char *sqlStatement)'],['../class_kompex_1_1_s_q_lite_statement.html#ac9dded83cf38639adb37ec749f1de58b',1,'Kompex::SQLiteStatement::SqlStatement(const std::wstring &amp;sqlStatement)'],['../class_kompex_1_1_s_q_lite_statement.html#a71956aa93224ebf0f0b006a4a6bbf220',1,'Kompex::SQLiteStatement::SqlStatement(const wchar_t *sqlStatement)']]],
  ['step',['Step',['../class_kompex_1_1_s_q_lite_statement.html#ab3e947774a0d44612886318b4e712d92',1,'Kompex::SQLiteStatement']]]
];

==> download.php?dl=KompexSQLiteWrapperDoxygen_1.10.12.tar.gz: KompexSQLiteWrapperDoxygen_1.10.12/search/all_73.js <==
var searchData=
[
  ['savedatabasefrommemorytofile',['SaveDatabaseFromMemoryToFile',['../class_kompex_1_1_s_q_lite_database.html#a3812e7e890ccee4489a7ec12d8b08f3c',1,'Kompex::SQLiteDatabase::SaveDatabaseFromMemoryToFile(const std::string &amp;filename=&quot;&quot;)'],['../class_kompex_1_1_s_q_lite_database.html#a79c8ef4fa3cb182e4f8fb7c103f160c8',1,'Kompex::SQLiteDatabase::SaveDatabaseFromMemoryToFile(const wchar_t *filename)']]],
  ['securetransaction',['SecureTransaction',['../class_kompex_1_1_s_q_lite_statement.html#a98943e3ce6e26a01b9c58bf01050bd33',1,'Kompex::SQLiteStatement::SecureTransaction(const char *sql)'],['../class_kompex_1_1_s_q_lite_statement.html#af5e97de1dd47d4d84ee02879927a5f0d',1,'Kompex::SQLiteStatement::SecureTransaction(const std::string sql)'],['../class_kompex_1_1_s_q_lite_statement.html#a64aa6c6c48b65fdec05163723b213e15',1,'Kompex::SQLiteStatement::SecureTransaction(const wchar_t *sql)']]],
  ['setsoftheaplimit',['SetSoftHeapLimit',['../class_kompex_1_1_s_q_lite_database.html#ac1a2d8526e91070eaa329abeaa926584',1,'Kompex::SQLiteDatabase']]],
  ['show',['Show',['../class_kompex_1_1_s_q_lite_exception.html#adf5425fa24f82d3fed40ae7374348a62',1,'Kompex::SQLiteException']]],
  ['sql',['Sql',['../class_kompex_1_1_s_q_lite_statement.html#a92e61596d95ea0e10c6cfe854d4dd97c',1,'Kompex::SQLiteStatement::Sql(const std::string &amp;sql)'],['../class_kompex_1_1_s_q_lite_statement.html#afcf5e04dadfe3dfd4f30bd96157de6b6',1,'Kompex::SQLiteStatement::Sql(const char *sql)'],['../class_kompex_1_1_s_q_lite_statement.html#a14933c42155e21268f6e1b3e62a77bde',1,'Kompex::SQLiteStatement::Sql(const std::wstring &amp;sql)'],['../class_kompex_1_1_s_q_lite_statement.html#a86e38aec89f694482c028c9bbfc04052',1,'Kompex::SQLiteStatement::Sql(const wchar_t *sql)']]],
  ['sqlaggregatefuncresult',['SqlAggregateFuncResult',['../class_kompex_1_1_s_q_lite_statement.html#aa2c1ad017ba60efee37b98819f1e8ca8',1,'Kompex::SQLiteStatement::SqlAggregateFuncResult(const std::string &amp;countSql)'],['../class_kompex_1_1_s_q_lite_statement.html#a8488d05fc3c0d36deb1fde0d27a90339',1,'Kompex::SQLiteStatement::SqlAggregateFuncResult(wchar_t *countSql)'],['../class_kompex_1_1_s_q_lite_statement.html#aa8f3bd27d91d1bd42c666c00812870a6',1,'Kompex::SQLiteStatement::SqlAggregateFuncResult(const char *countSql)']]],
  ['sqliteblob',['SQLiteBlob',['../class_kompex_1_1_s_q_lite_blob.html',1,'Kompex']]],
  ['sqliteblob',['SQLiteBlob',['../class_kompex_1_1_s_q_lite_blob.html#a5dbd102cbd365507e9ad2f5e399e11de',1,'Kompex::SQLiteBlob::SQLiteBlob()'],['../class_kompex_1_1_s_q_lite_blob.html#a6f9401272a8bb90bb18eb7b35ea5b6d5',1,'Kompex::SQLiteBlob::SQLiteBlob(SQLiteDatabase *db, std::string symbolicDatabaseName, std::string tableName, std::string columnName, int64 rowId, BLOB_ACCESS_MODE accessMode=BLOB_READWRITE)']]],
  ['sqlitedatabase',['SQLiteDatabase',['../class_kompex_1_1_s_q_lite_database.html',1,'Kompex']]],
  ['sqlitedatabase',['SQLiteDatabase',['../class_kompex_1_1_s_q_lite_database.html#afb155f1329a190446144a1a30c9bae0f',1,'Kompex::SQLiteDatabase::SQLiteDatabase()'],['../class_kompex_1_1_s_q_lite_database.html#aa6a11b3db582b88901e08f44dd616906',1,'Kompex::SQLiteDatabase::SQLiteDatabase(const char *filename, int flags, const char *zVfs)'],['../class_kompex_1_1_s_q_lite_database.html#a3f3d2d17f265e16ad37c8d6c78140fee',1,'Kompex::SQLiteDatabase::SQLiteDatabase(const std::string &amp;filename, int flags, const char *zVfs)'],['../class_kompex_1_1_s_q_lite_database.html#a850b764cee6e62d6fafe486d7b8ef9da',1,'Kompex::SQLiteDatabase::SQLiteDatabase(const wchar_t *filename)']]],
  ['sqliteexception',['SQLiteException',['../class_kompex_1_1_s_q_lite_exception.html#a76b818cf33dfdd031b16cea1e6d8950d',1,'Kompex::SQLiteException::SQLiteException(const std::string &amp;filename, unsigned int lineNumber, std::string errDescription=&quot;&quot;, int internalSqliteResultCode=-1)'],['../class_kompex_1_1_s_q_lite_exception.html#a0af6637c67903c5a378b8d011abdd7ea',1,'Kompex::SQLiteException::SQLiteException(const std::string &amp;filename, unsigned int lineNumber, const char *errDescription=&quot;&quot;, int internalSqliteResultCode=-1)']]],
  ['sqliteexception',['SQLiteException',['../class_kompex_1_1_s_q_lite_exception.html',1,'Kompex']]],
  ['sqlitestatement',['SQLiteStatement',['../class_kompex_1_1_s_q_lite_statement.html',1,'Kompex']]],
  ['sqlitestatement',['SQLiteStatement',['../class_kompex_1_1_s_q_lite_statement.html#a99ef96c28884e3e0e60455589dda363a',1,'Kompex::SQLiteStatement']]],
  ['sqlresultblob',['SqlResultBlob',['../class_kompex_1_1_s_q_lite_statement.html#ace1f5cc6c309ac0af4110281a893b0be',1,'Kompex::SQLiteStatement']]],
  ['sqlresultcstring',['SqlResultCString',['../class_kompex_1_1_s_q_lite_statement.html#a7cd9332b0bdc9f357afd8fbf76f53a36',1,'Kompex::SQLiteStatement']]],
  ['sqlresultstring16',['SqlResultString16',['../class_kompex_1_1_s_q_lite_statement.html#abe7a8e3eefd854d8766dee84235d7177',1,'Kompex::SQLiteStatement']]],
  ['sqlstatement',['SqlStatement',['../class_kompex_1_1_s_q_lite_statement.html#aa489e189a08bef44ed00640a5ad27b01',1,'Kompex::SQLiteStatement::SqlStatement(const std::string &amp;sqlStatement)'],['../class_kompex_1_1_s_q_lite_statement.html#aa946886e893ac5f8e36452183ab4fa10',1,'Kompex::SQLiteStatement::SqlStatement(const char *sqlStatement)'],['../class_kompex_1_1_s_q_lite_statement.html#ac9dded83cf38639adb37ec749f1de58b',1,'Kompex::SQLiteStatement::SqlStatement(const std::wstring &amp;sqlStatement)'],['../class_kompex_1_1_s_q_lite_statement.html#a71956aa93224ebf0f0b006a4a6bbf220',1,'Kompex::SQLiteStatement::SqlStatement(const wchar_t *sqlStatement)']]],
  ['step',['Step',['../class_kompex_1_1_s_q_lite_statement.html#ab3e947774a0d44612886318b4e712d92',1,'Kompex::SQLiteStatement']]]
];
